# lightkube-extensions
A collection of helpers and shared code for using [Lightkube](https://lightkube.readthedocs.io/en/latest/)

Many of these helpers are vendored from or inspired by [Charmed Kubeflow Chisme](https://github.com/canonical/charmed-kubeflow-chisme)

## Publishing to PyPI

To release a new version of this package to PyPI, you can create a Github release with the new version number (eg: 0.1.2). The release will trigger a workflow that builds the package and publishes it to PyPI.
